unit uZeit;
(* ******************************************************************** *)
(*                                                                      *)
(* K L A S S E : TZeit                                                  *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.1                                                    *)
(* Autor       : S. Spolwig, Berlin                                     *)
(*                                                                      *)
(* Beschreibung: stellt ein Objekt ZEIT vom Typ TZeit mit Stopuhrfunk-  *)
(*               tionen zur Verfgung.                                  *)
(* Compiler    : DELPHI 2007                                            *)
(* Aenderung   : V. 1.0                                                 *)
(*               V. 1.1                                                 *)
(*               V. 1.1.1 Setpause krzere Intervalle                   *)
(* ******************************************************************** *)

interface
(* ==================================================================== *)
uses  Windows, Messages, Sysutils, Forms;


type
  TZeit = class (TObject)
    protected
    Startzeit,
    Stopzeit,
    Laufzeit  : longint;
    public
    function  GetDatum  : string;             virtual;
    function  GetUhrzeit: string;             virtual;
    function  GetStart  : longint;            virtual;
    function  GetStop   : longint;            virtual;
    function  GetStopZeit: longint;           virtual;
    function  GetStopZeitForm : string;       virtual;
    procedure SetPause (millisec : longint);  virtual;
    procedure Start;                          virtual;
    procedure Stop;                           virtual;
  end;

var Zeit : TZeit;

(* ----------------- B e s c h r e i b u n g -------------------------

Oberklasse    : TObject
Bezugsklassen : s.o.

Methoden

GetDatum
  Anfrage: aktuelles Datum liefern im Format : TT.MM.JJ

GetZeit
  Anfrage: aktuelle Uhrzeit liefern im Format : STST:MM.SS

GetStart, GetStop
  Anfrage: liefert Zeitpunkt in ms.

GetStopZeit
  Anfrage: Verstrichene Zeit zwischen Start und Stop in MilliSek.

GetStopZeitForm
   Anfrage: Verstrichene Zeit zwischen Start und Stop im Format 0000:000

Start
  Auftrag: Stopuhr starten

Stop
  Auftrag: Stopuhr anhalten und Laufzeit merken

SetPause
  Auftrag: Zeitschleife in Millisek. starten



 ---------------------------------------------------------------------- *)

implementation
(* ==================================================================== *)

procedure TZeit.Start;
(* -------------------------------------------------------------------- *)
begin
  startzeit := 0;
  startzeit := GetTickCount;
end;

procedure TZeit.Stop;
(* -------------------------------------------------------------------- *)
begin
 stopzeit := 0;
 stopzeit := GetTickCount;
 Laufzeit := Stopzeit - Startzeit ;
end;

function  TZeit.GetStart  : longint;
(* -------------------------------------------------------------------- *)
begin
  Result := Startzeit;
end;


function  TZeit.GetStop  : longint;
(* -------------------------------------------------------------------- *)
begin
  Result := Stopzeit;
end;


function TZeit.GetStopZeit : longint;
(* -------------------------------------------------------------------- *)
begin
  Result := Laufzeit ;
end;


function TZeit.GetStopZeitForm : string;
(* -------------------------------------------------------------------- *)
begin
  if Laufzeit < 1000
  then Result := '0:' + inttostr(Laufzeit)
  else
    begin
      Result := inttostr(Laufzeit DIV 1000) +':' + inttostr(Laufzeit MOD 1000)
    end;
end;

function TZeit.GetDatum : string;
(* -------------------------------------------------------------------- *)
begin
  Result := DateToStr(now)
end;


function TZeit.GetUhrzeit : string;
(* -------------------------------------------------------------------- *)
begin
  Result := TimeToStr(now)
end;

procedure TZeit.SetPause(millisec : longint);
(* -------------------------------------------------------------------- *)
var i : LongInt;
begin
 for i := 1 to 22400 * millisec do  // ca. 1 mSek Bratzeit
   Application.ProcessMessages;

{
var zeit1 : longint;
begin                               // auch nicht viel besser
  zeit1 := GetTickCount;
  repeat
    application.ProcessMessages;
  until ((GetTickCount - zeit1) > millisec);
}
end;
(* ==================================================================== *)
initialization
  Zeit := TZeit.create;
end.
